# Conveyor stubs

This is a package providing type stubs for use with [Conveyor](https://conveyordata.com/).

In case you're facing any issues with this package, feel free to reach out to us on our [support channel](https://conveyordata.slack.com/),
or your dedicated company channel in case you have an Enterprise subscription.
